@@ -8,11 +8,14 @@ from pydantic import ConfigDict, Field
 
 from entitysdk.models.base import BaseModel
 from entitysdk.models.core import Identifiable
+from entitysdk.types import ID, AssetLabel, AssetStatus, ContentType, StorageType
 
 
 class Asset(Identifiable):
     """Asset."""
 
+    id: ID
+
     path: Annotated[
         str,
         Field(
@@ -32,7 +35,7 @@ class Asset(Identifiable):
         ),
     ]
     content_type: Annotated[
-        str,
+        ContentType,
         Field(
             examples=["image/png", "application/json"],
             description="The content type of the asset.",
@@ -52,7 +55,7 @@ class Asset(Identifiable):
         ),
     ] = None
     status: Annotated[
-        str | None,
+        AssetStatus | None,
         Field(
             examples=["created", "deleted"],
             description="The status of the asset.",
@@ -62,7 +65,7 @@ class Asset(Identifiable):
         dict,
         Field(description="Asset json metadata."),
     ] = {}
-    label: Annotated[str | None, Field(description="Optional asset label.")] = None
+    label: Annotated[AssetLabel, Field(description="Asset label.")]
 
 
 class LocalAssetMetadata(BaseModel):
@@ -81,7 +84,7 @@ class LocalAssetMetadata(BaseModel):
         ),
     ]
     content_type: Annotated[
-        str,
+        ContentType,
         Field(
             examples=["image/png"],
             description="The content type of the asset.",
@@ -93,6 +96,58 @@ class LocalAssetMetadata(BaseModel):
             description="The metadata of the asset.",
         ),
     ] = None
+    label: Annotated[AssetLabel, Field(description="Mandatory asset label.")]
+
+
+class ExistingAssetMetadata(BaseModel):
+    """An existing asset to register."""
+
+    model_config = ConfigDict(
+        extra="forbid",
+        arbitrary_types_allowed=True,
+    )
+
+    path: Annotated[
+        str,
+        Field(
+            examples=["image.png"],
+            description="The name of the file or directory, without leading components.",
+        ),
+    ]
+    full_path: Annotated[
+        str,
+        Field(
+            examples=["path/to/image.png"],
+            description="The full remote path of the file or directory, without the bucket.",
+        ),
+    ]
+    storage_type: Annotated[
+        StorageType,
+        Field(
+            examples=["aws_s3_open"],
+            description="Storage where the asset is located.",
+        ),
+    ]
+    is_directory: Annotated[
+        bool,
+        Field(
+            description="Whether the asset is a directory.",
+        ),
+    ]
+    content_type: Annotated[
+        ContentType,
+        Field(
+            examples=["image/png"],
+            description="The content type of the asset.",
+        ),
+    ]
+    label: Annotated[
+        AssetLabel,
+        Field(
+            examples=["morphology"],
+            description="Mandatory asset label.",
+        ),
+    ]
 
 
 class DetailedFile(BaseModel):
