@@ -6,17 +6,14 @@ from entitysdk.models.brain_region import BrainRegion
 from entitysdk.models.entity import Entity
 from entitysdk.models.license import License
 from entitysdk.models.subject import Subject
-from entitysdk.types import ID
 
 
 class ScientificArtifact(Entity):
     """Scientific artifact base model."""
 
     experiment_date: datetime | None = None
-    contact_id: ID | None = None
-    atlas_id: ID | None = None
-
-    subject: Subject
-    brain_region: BrainRegion
-
+    contact_email: str | None = None
+    subject: Subject | None = None
+    brain_region: BrainRegion | None = None
     license: License | None = None
+    published_in: str | None = None
